Bank Marketing Data Set

This dataset is related to a direct marketing campaigns (phone calls) of a Portuguese banking institution.
The marketing campaigns were based on phone calls.
Often, more than one contact to the same client was required,
in order to access if the product (bank term deposit) would be or not subscribed.

Features recorded before the contact event are removed from the original dataset to avoid data leakage.
Only clients with a positive balance are considered, since clients in debt are not eligible for term deposits.

=================   ==============
Classes                          2
Subscribers                   4787
Non-subscribers              33144
Samples                      37931
Features                        10
=================   ==============

For more information, read the User Guide https://empulse.readthedocs.io/en/latest/guide/datasets_guide.html
